@@ -345,33 +345,83 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
 
             if team == good_team:
 
-                legend_elements = [Line2D([0], [0], color = colors[team]['SHOT'], marker = 'o',
-                                    markerfacecolor = colors[team]['GOAL'], label = 'GOAL', markersize = 20),
-                                    
-                                    Line2D([0], [0], marker='o', color = colors[team]['SHOT'], label= 'SHOT',
-                                        markerfacecolor = colors[team]['SHOT'], markersize = 20),
+                if size == None:
 
-                                   Line2D([0], [0], marker='o', color = colors[team]['MISS'], label= 'MISS',
-                                    markerfacecolor = colors[team]['MISS'], markersize = 20)]
-
-                legend = ax.legend(handles = legend_elements, loc="lower center", ncol=3, title = f'{team}', fontsize = 14,
+                    legend = ax.legend(loc="lower center", ncol=3, title = f'{team}', fontsize = 14,
                                     title_fontsize = 16, facecolor = 'white', framealpha = 1,
                                     edgecolor = 'gray').set_zorder(-1)
+
+                else:
+
+                    legend_elements = list()
+
+                    for result, color in colors[team].items():
+
+                        if result == 'GOAL':
+
+                            edge_color = colors[team]['SHOT']
+
+                        else:
+
+                            edge_color = color
+
+                        element = Line2D([0], [0], markeredgecolor = edge_color, marker = 'o', markerfacecolor = color,
+                                    label = result, markersize = 14, color = 'w')
+
+                        legend_elements.append(element)
+
+
+                #legend_elements = [Line2D([0], [0], markeredgecolor = colors[team]['SHOT'], marker = 'o',
+                #                    markerfacecolor = colors[team]['GOAL'], label = 'GOAL', markersize = 14, color = 'w',),
+                #                    
+                #                    Line2D([0], [0], marker='o', markeredgecolor = colors[team]['SHOT'], label= 'SHOT',
+                #                        color = 'w', markerfacecolor = colors[team]['SHOT'], markersize = 14),
+                #
+                #                   Line2D([0], [0], marker='o', color = colors[team]['MISS'], label= 'MISS',
+                #                    markerfacecolor = colors[team]['MISS'], markersize = 14, color = 'w',)]
+
+                    legend = ax.legend(handles = legend_elements, loc="lower center", ncol=3, title = f'{team}', fontsize = 14,
+                                        title_fontsize = 16, facecolor = 'white', framealpha = 1,
+                                        edgecolor = 'gray').set_zorder(-1)
   
             if team == bad_team:
 
-                legend_elements = [Line2D([0], [0], color = colors[team]['SHOT'], marker = 'o',
-                                    markerfacecolor = colors[team]['GOAL'], label = 'GOAL', markersize = 20),
-                                    
-                                    Line2D([0], [0], marker='o', color = colors[team]['SHOT'], label= 'SHOT',
-                                        markerfacecolor = colors[team]['SHOT'], markersize = 20),
+                if size == None:
 
-                                   Line2D([0], [0], marker='o', color = colors[team]['MISS'], label= 'MISS',
-                                    markerfacecolor = colors[team]['MISS'], markersize = 20)]
-
-                legend = ax.legend(handles = legend_elements, loc="upper center", ncol=3, title = f'{team}', fontsize = 14,
+                    legend = ax.legend(loc="upper center", ncol=3, title = f'{team}', fontsize = 14,
                                     title_fontsize = 16, facecolor = 'white', framealpha = 1,
                                     edgecolor = 'gray').set_zorder(-1)
+
+                else:
+
+                    for result, color in colors[team].items():
+
+                        if result == 'GOAL':
+
+                            edge_color = colors[team]['SHOT']
+
+                        else:
+
+                            edge_color = color
+
+                        element = Line2D([0], [0], markeredgecolor = edge_color, marker = 'o', markerfacecolor = color,
+                                    label = result, markersize = 14, color = 'w')
+
+                        legend_elements.append(element)
+
+
+                #legend_elements = [Line2D([0], [0], markeredgecolor = colors[team]['SHOT'], marker = 'o',
+                #                    markerfacecolor = colors[team]['GOAL'], label = 'GOAL', markersize = 14, color = 'w',),
+                #                    
+                #                    Line2D([0], [0], marker='o', markeredgecolor = colors[team]['SHOT'], label= 'SHOT',
+                #                       markerfacecolor = colors[team]['SHOT'], markersize = 14, color = 'w',),
+                #
+                #                   Line2D([0], [0], marker='o', markeredgecolor = colors[team]['MISS'], label= 'MISS',
+                #                    markerfacecolor = colors[team]['MISS'], markersize = 14, color = 'w',)]
+
+                    legend = ax.legend(handles = legend_elements, loc="upper center", ncol=3, title = f'{team}', fontsize = 14,
+                                        title_fontsize = 16, facecolor = 'white', framealpha = 1,
+                                        edgecolor = 'gray').set_zorder(-1)
                 
 
         if save_img == True:
